@@ -104,7 +104,9 @@ class Authenticator(models.Model):
     def _get_metadata(self) -> Optional['AuthenticatorMetadata']:
         """Get the appropriate metadata."""
         # First test the presence of aaguid - FIDO 2
-        if self.attestation.auth_data.credential_data.aaguid != NULL_AAGUID:
+        if hasattr(self.attestation.auth_data, 'credential_data') and \
+                self.attestation.auth_data.credential_data is not None and \
+                self.attestation.auth_data.credential_data.aaguid != NULL_AAGUID:
             identifier = str(UUID(b2a_hex(self.credential.aaguid).decode()))
             try:
                 return AuthenticatorMetadata.objects.get(identifier=identifier)
@@ -135,7 +137,7 @@ class Authenticator(models.Model):
         """Prepare crypto store for verification."""
         store = crypto.X509Store()
         for root_cert in root_certs:
-            cert = crypto.load_certificate(crypto.FILETYPE_PEM, PEM_CERT_TEMPLATE.format(root_cert))
+            cert = crypto.load_certificate(crypto.FILETYPE_PEM, PEM_CERT_TEMPLATE.format(root_cert).encode())
             store.add_cert(cert)
         if len(self.attestation.att_statement['x5c']) > 1:
             for interm_cert in self.attestation.att_statement['x5c'][1:]:
@@ -158,10 +160,13 @@ class Authenticator(models.Model):
             return metadata
         # Take the device certificate and try to validate against all certs in MDS
         device_cert = crypto.load_certificate(crypto.FILETYPE_ASN1, self.attestation.att_statement['x5c'][0])
-        try:
+        if metadata.detailed_metadata_entry != '':
             root_certs = json.loads(metadata.detailed_metadata_entry)['attestationRootCertificates']
-        except KeyError:
-            root_certs = json.loads(metadata.metadata_entry)['attestationRootCertificates']
+        else:
+            root_certs = json.loads(metadata.metadata_entry).get('metadataStatement',
+                                                                 {}).get('attestationRootCertificates', [])
+            if not root_certs:
+                return metadata
         store = self._prepare_store(root_certs)
         store_ctx = crypto.X509StoreContext(store, device_cert)
         try:
